Module wallpaper

Module wallpaper 

Wallpaper management module with cross-platform backend support

Modules

backends

Functions

apply_wallpaper
Set wallpaper using the best available backend
apply_wallpaper_daemon
Set wallpaper with fire-and-forget option (for daemon mode)
list_backends
List all available wallpaper backends
platform_info
Get information about the current platform and available backends
set_from_source
Download and set wallpaper from any registered source The query parameter contains additional arguments (e.g., search terms, subreddit names)
set_from_source_daemon
Download and set wallpaper from source (daemon mode - fire and forget)
set_local
Set wallpaper from local collection
set_local_daemon
Set wallpaper from local collection (daemon mode - fire and forget)